@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 
 from freezerbox import load_db
-from schema_helpers import *
+from param_helpers import *
 
 # Only cases where the database cannot be loaded are tested here.  The cases 
 # where the database can be successfully loaded are tested with the loaders 
@@ -10,7 +10,7 @@ from schema_helpers import *
 @parametrize_from_file(
         schema=Schema({
             'config': {str: eval},
-            'error': error,
+            'error': with_freeze.error,
         }),
 )
 def test_load_db_err(config, error):
